#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.11.0
%define plugin pulseaudio
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        0.4.8
Release:        bp156.1.3
Summary:        Pulseaudio Volume Control Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Mixers
URL:            https://docs.xfce.org/apps/pulseaudio-plugin/start
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/0.4/%{name}-%{version}.tar.bz2
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exo-2) >= 0.11
BuildRequires:  pkgconfig(glib-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
BuildRequires:  pkgconfig(libpulse-mainloop-glib) >= 0.9.19
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= 4.11.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.11.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.9.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.6.0
# optional requirements
BuildRequires:  pkgconfig(gio-2.0) >= 2.42
BuildRequires:  pkgconfig(keybinder-3.0) >= 0.2.2
BuildRequires:  pkgconfig(libcanberra) >= 0.30
BuildRequires:  pkgconfig(libnotify) >= 0.7.0
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.20
%if 0%{?sle_version} && 0%{?sle_version} < 150300
Requires:       pulseaudio
%else
Requires:       pulseaudio-daemon
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
Recommends:     pavucontrol
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
Xfce4-pulseaudio-plugin is a panel plugin for controlling an audio
output volume of the PulseAudio mixer. The volume can be adjusted using
keyboard shortcuts, mouse wheel, a slider in a popup menu, or via
a linked external audio mixer tool.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    %{name}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode
%else
%configure
%endif
%make_build

%install
%make_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libpulseaudio-plugin.la

%find_lang %{name} %{?no_lang_C}

%files
%doc ChangeLog README.md
%license COPYING
%{_libdir}/xfce4/panel/plugins/libpulseaudio-plugin.so
%{_datadir}/xfce4/panel/plugins/pulseaudio.desktop
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/status/*

%files lang -f %{name}.lang

%changelog
* Sun Oct  1 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.4.8
  * MPRIS: Use D-Bus name for identifying players
  * Fix possible context menu crash with MPRIS playlist
  * Add option to make mic icon persistent
  * Check for mic widget visibility
  * Preserve channel balance when changing sink/source volume
  * MPRIS: Add option to send multimedia keys to all players
  * MPRIS: Fix default controlled player by multimedia keys
  * Remove dead code
  * Translation Updates
* Thu Jun  1 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.4.7
  * Fix crash when D-Bus connection is lost before it's connected
  * Fix copyright info
  * MPRIS: Control recently open/used player using multimedia keys
  * Deduplicate key binding code
  * Bind all possible keys
  * Update about authors
  * MPRIS: Remove old settings when clearing known players
  * MPRIS: Ignore multimedia keys for blacklisted players
  * MPRIS: Add possibility to hide inactive players, improve config
    storage
  * MPRIS: Remove pulseaudio_mpris_player_can_launch function
  * MPRIS: Fix memory leak in player finalize
  * MPRIS: Remove unused pulseaudio_mpris_player_is_equal function
  * MPRIS: Refactor player connection lost and finalize
  * MPRIS: Deduplicate find_desktop_entry function
  * MPRIS: Make pulseaudio_mpris_get_available_players static
  * MPRIS: Check for filename before launching the player
  * Improve connection/disconnection with server
  * Menu: Don't clear structure, it's not needed
  * MPRIS: Reduce player_is_usable timeout to 5 sec
  * MPRIS: Memory management fixes
  * MPRIS: Don't initialize struct members, GLib is doing it
  * MPRIS: Micro-optimization
  * MPRIS: Check for is_playing in set_can_play function
  * Subscribe NameOwnerChanged to watch MPRIS changes instead of
    timer
  * Fix removing blacklisted MPRIS players from config
  * Improve run mixer button sensitivity
  * Display default device name in tooltip
  * Don't set has-tooltip property twice
  * Don't show recording indicator for non-default monitors
  * Make run mixer button sensitive for any path
  * Show unplugged devices as insensitive
  * Don't show rec icon if the source output doesn't belong to any
    client
  * Don't show recording indicator when it's not connected to the
    source
  * Fix mistake in comment
  * Don't reset recording value in callback
  * Allow maximum volume configuration in dialog
  * Improve volume step size text
  * Translation Updates
- Remove _service file
* Sat Apr  1 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.4.6
  * Fix changing default sink and source devices
  * Fix flickering mic icon when recording application is connected
  * Avoid critical from xfce4-notifyd if gauge_value > 100
  * Display maximum volume of all channels instead of volume of
    left channel
  * Add recording base volume indicator
  * Control mic volume/mute when mouse cursor is over the mic icon
  * Lower warning level
  * Improve volume notifications settings
  * Show volume notifications from hotkeys according to comment
  * Don't set negative volume from hotkeys
  * Use correct variable for "volume-mic-changed" signal ID
  * Don't force set the default device
  * Set recording icon according to recording volume level
  * Show source monitor if it is a default source
  * Check for recording state on context ready
  * Allow volume step configuration in dialog
    (gxo#panel-plugins/xfce4-pulseaudio-plugin#28)
  * wnck: Add missing LIBS/CFLAGS in Makefile
  * wnck: Use Libxfce4windowing when available
  * wnck: Guard X11 code path to prevent crash on Wayland
  * wnck: Improve RaiseWnck a bit
  * Fix memory leak
  * cleanup: Fix formatting
  * Fix blurry media player icon from file when UI scale > 1
  * Fix blurry icons in prefs dialog when UI scale factor > 1
  * Use "logo-icon-name" instead of "logo" in about dialog
  * Do not override fatal log level
  * build: Bump GLib minimum required to 2.44
  * Translation Updates
* Fri Sep 16 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.4.5
  * Use Source Output Info for recording indicator
    to reduce flickering (gxo#panel-plugins/xfce4-pulseaudio-plugin#81)
    and to hide it with pavucontrol
    (gxo#panel-plugins/xfce4-pulseaudio-plugin#80)
  * Display notification on mic volume changes
    (gxo#panel-plugins/xfce4-pulseaudio-plugin#42)
  * Fix accidental toggling of the mute switch
    (gxo#panel-plugins/xfce4-pulseaudio-plugin#64)
  * Show notification even when volume is already at max/min
    (gxo#panel-plugins/xfce4-pulseaudio-plugin#52)
  * Optionally play system sound on volume changes
    (gxo#panel-plugins/xfce4-pulseaudio-plugin#4)
  * Fix menu position when panel autohide is enabled
  * Fix compilation with gcc 10
  * about: Bump copyright year
  * Fix typos
  * Translation Updates
* Sat Sep  3 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 0.4.4
  - Add a recording indicator
  - Filter out multiple button press events
  - Bump urls
  - Fix make distcheck
  - autoconf: AC_OUTPUT -> AC_CONFIG_FILES + AC_OUTPUT
  - Update `.gitignore`
  - Create new README.md. Update configure.ac.in
  - Add basic GitLab pipeline
  - Translation Updates
* Thu Feb 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Require the pulseaudio-daemon capability instead of the
  pulseaudio package, so alternative implementations can be used
  (boo#1182730).
* Sun Mar 29 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.4.3
  * Build now requires exo-2 0.11 or newer
  * Fixed various memory leaks and warnings
  * Removed unused dbus-glib include (bxo#15343)
  * Replaced g_type_class_add_private deprecations
  * Updated copyright years
  * Updated URLs from goodies.x.o to docs.x.o (bxo#16173)
  * MPRIS: Added support for filename icons (bxo#14329)
  * MPRIS: Added support for single-string variants on xesam:artist
  * MPRIS: Added support for the DesktopEntry property (bxo#14412)
  * MPRIS: Added support for the plasma-browser-integration plugin
    (bxo#15487)
  * MPRIS: Added title/artist conditioning from the track title
  * Preferences: Fixed icon rendering known players
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.4.2
  * Preferences: Improve spacing
  * Translation Updates
* Fri Jul 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up specfile
* Wed Jun  5 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added bcond for GIT master sources
- Added OBS service file to fetch git master sources when needed
- Cleaned up spec file
- Dropped Leap 42.3 conditionals (obsolete)
* Sun Apr 28 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added missing dependency pkgconfig(dbus-glib-1)
* Thu Apr 26 2018 seife+obs@b1-systems.com
- update to version 0.4.1
  * Translation updates
* Sat Mar 24 2018 seife+obs@b1-systems.com
- update to version 0.4.0: Stable Release!
  * Use correct player names and icons in media player preferences
  * Translation Updates
* Fri Mar  2 2018 seife+obs@b1-systems.com
- update to version 0.3.5:
  * New Feature: Move streams on default output device change (bxo#14157)
  - Prior to this update, when a new output device was selected, any
    existing streams had to be moved using pavucontrol. This change
    automatically moves any active output streams to the newly
    selected device.
  * New Feature: Management of known MPRIS2 players (bxo#13903)
  - Known players can now be cleared or selectively hidden from the menu.
  * Bug Fixes:
  - Wait for the pulseaudio volume sink to be connected to get the
    current volume state at startup (bxo#14071, bxo#13677)
  - MPRIS2: stale data retained after Metadata signal (bxo#14068)
  * Translation Updates
* Sun Dec 10 2017 seife+obs@b1-systems.com
- update to version 0.3.4:
  * New Feature: MPRIS Playlist Support
  - Implements the org.mpris.MediaPlayer2.Playlists specification.
  - The most recent 5 playlists are displayed (if supported by the player).
  * New Feature: Experimental libwnck Support
  - Some media players do not support the Raise method. This optional
    feature attempts to raise windows by their title.
  * General:
  - Unexpected error messages sent via DBUS are now handled gracefully.
  - Numerous memory leaks patched.
  * Translation Updates
* Tue Nov 28 2017 seife+obs@b1-systems.com
- update to version 0.3.3:
  * New Feature: Multimedia Key Support
  - Integrates with the recently added MPRIS2 support
  - Extends multimedia key support to all MPRIS2-enabled media players
  * General:
  - Simplified device menus
  - Improved default volume scale increments (steps of 5, max of 150)
  - More code cleanup, dropping unused IDO functions
  * Bug Fixes:
  - bxo#13677: Show volume change notifications when changed with
    another application
  - bxo#13908: Change default device when changed with another application
  - bxo#13961: Fix flag in g_bus_watch_name_on_connection() method
  - bxo#13998: Fix plugin size calculation with multiple rows
  * Translation Updates
* Fri Nov 10 2017 seife+obs@b1-systems.com
- update to version 0.3.2:
  - Replace deprecated notify_notification_set_hint calls
  - Fix build with clang (bxo#13889)
  - Fix panel icon size with high DPI (bxo#13894)
  - Translation Updates
* Tue Oct  3 2017 seife+obs@b1-systems.com
- update to version 0.3.1:
  - New Features:
  - Device Management
  - Switch active audio input and output devices
  - Control volume of the currently selected device
  - Without input or output devices, the menu items are hidden
  - Does not change the device associated with active streams
  - Add audio input volume to plugin menu
  - Add (optional) MPRIS2 media player controls
  - Add support for the XF86AudioMicMute key
  - Update help links to the new docs.xfce.org startpage
  - Set the transient hint for volume and mic notifications
  - General:
  - Fixed build warnings with gcc-7
  - Improved code quality with the custom widgets
  - Improved memory management
  - Simplified audio volume controls
  - Updated credits and copyright notice
  - Translation Updates
* Sat Jul  8 2017 seife+obs@b1-systems.com
- update to version 0.2.5:
  - no upstream changelog
  - added translations
- add -lang package
* Sun Feb 26 2017 tiwai@suse.de
- Add pavucontrol to recommends, as it's invoked from the menu
- Build with libnotify to show OSD properly
* Sat Jun 13 2015 sb73542@yahoo.com
- update to version 0.2.4
  - Added a GUI control for show-notifications
  - Added a configuration option "show-notifications"
  - Reconnect to the PA server if the connection is lost
  - Use volume-changed signal to update notifications
* Tue May 12 2015 gber@opensuse.org
- update to version 0.2.3
  - corrected copyright and author list
  - added OSD notifications
  - >100%% audio volume is now allowed (only when using a volume
    slider)
* Thu Mar 26 2015 gber@opensuse.org
- update to version 0.2.2
  - Fixed crashes&lockups with Gtk+-3.14
  - Icon fixes
  - Added plugin icon
  - Added required icons to tarball
* Mon Mar  9 2015 gber@opensuse.org
- update to version 0.2.1
  - incorrect mouse coordinate translation in the volume slider
  - crash on menu popup/popdown
* Thu Mar  5 2015 gber@opensuse.org
- update to version 0.2.0
  - Added a popup menu with a volume slider, mute item and an audio
    mixer command
  - Numerous build fixes
  - Documentation and description fixes
  - Switched to symbolic icons
  - Switched to gtk error message boxes
  - Updated text of GPL license
* Thu Feb 19 2015 gber@opensuse.org
- initial packaging
